macro_rules! d_println {
() => { ... };
($($arg:tt)*) => { ... };
}Expand description
Prints to the stdout with newline in debug mode only
macro_rules! d_println {
() => { ... };
($($arg:tt)*) => { ... };
}Prints to the stdout with newline in debug mode only